The ``TTFPATH`` and ``AFMPATH`` environment variables
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Support for the (undocumented) ``TTFPATH`` and ``AFMPATH`` environment
variables has been removed. Register additional fonts using
``matplotlib.font_manager.fontManager.addfont()``.

mathtext ``Glue`` classes
~~~~~~~~~~~~~~~~~~~~~~~~~
The following have been removed from `matplotlib.mathtext`:

* *copy* parameter of ``mathtext.Glue``
* ``mathtext.Glue.glue_subtype``
* ``mathtext.GlueSpec``
* ``Fil``, ``Fill``, ``Filll``, ``NegFil``, ``NegFill``, ``NegFilll``, and
  ``SsGlue``; directly construct glue instances with ``Glue("fil")``, etc.

*ismath* parameter of ``draw_tex``
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
The *ismath* parameter of the ``draw_tex`` method of all renderer classes has
been removed (as a call to ``draw_tex`` -- not to be confused with
``draw_text``! -- means that the entire string should be passed to the
``usetex`` machinery anyways). Likewise, the text machinery will no longer pass
the *ismath* parameter when calling ``draw_tex`` (this should only matter for
backend implementers).

Passing ``ismath="TeX!"`` to `.RendererAgg.get_text_width_height_descent` is no
longer supported; pass ``ismath="TeX"`` instead,
